#[non_exhaustive]pub struct DiskEncryptionConfigurationBuilder { /* private fields */ }Expand description
A builder for DiskEncryptionConfiguration.
Implementations
Sourceimpl DiskEncryptionConfigurationBuilder
impl DiskEncryptionConfigurationBuilder
Sourcepub fn encryption_context(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn encryption_context( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to encryption_context.
To override the contents of this collection use set_encryption_context.
Specifies the optional encryption context that will be used when encrypting the data. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data.
Sourcepub fn set_encryption_context(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_encryption_context( self, input: Option<HashMap<String, String>>, ) -> Self
Specifies the optional encryption context that will be used when encrypting the data. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data.
Sourcepub fn get_encryption_context(&self) -> &Option<HashMap<String, String>>
pub fn get_encryption_context(&self) -> &Option<HashMap<String, String>>
Specifies the optional encryption context that will be used when encrypting the data. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data.
Sourcepub fn encryption_key_arn(self, input: impl Into<String>) -> Self
pub fn encryption_key_arn(self, input: impl Into<String>) -> Self
The KMS key ARN to encrypt local disks.
Sourcepub fn set_encryption_key_arn(self, input: Option<String>) -> Self
pub fn set_encryption_key_arn(self, input: Option<String>) -> Self
The KMS key ARN to encrypt local disks.
Sourcepub fn get_encryption_key_arn(&self) -> &Option<String>
pub fn get_encryption_key_arn(&self) -> &Option<String>
The KMS key ARN to encrypt local disks.
Sourcepub fn build(self) -> DiskEncryptionConfiguration
pub fn build(self) -> DiskEncryptionConfiguration
Consumes the builder and constructs a DiskEncryptionConfiguration.