#[non_exhaustive]pub struct DiskEncryptionConfiguration {
pub encryption_context: Option<HashMap<String, String>>,
pub encryption_key_arn: Option<String>,
}Expand description
The configuration object that allows encrypting local disks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_context: Option<HashMap<String, String>>Specifies the optional encryption context that will be used when encrypting the data. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data.
encryption_key_arn: Option<String>The KMS key ARN to encrypt local disks.
Implementations
Sourceimpl DiskEncryptionConfiguration
impl DiskEncryptionConfiguration
Sourcepub fn encryption_context(&self) -> Option<&HashMap<String, String>>
pub fn encryption_context(&self) -> Option<&HashMap<String, String>>
Specifies the optional encryption context that will be used when encrypting the data. An encryption context is a collection of non-secret key-value pairs that represent additional authenticated data.
Sourcepub fn encryption_key_arn(&self) -> Option<&str>
pub fn encryption_key_arn(&self) -> Option<&str>
The KMS key ARN to encrypt local disks.
Sourceimpl DiskEncryptionConfiguration
impl DiskEncryptionConfiguration
Sourcepub fn builder() -> DiskEncryptionConfigurationBuilder
pub fn builder() -> DiskEncryptionConfigurationBuilder
Creates a new builder-style object to manufacture DiskEncryptionConfiguration.