Session

Struct Session 

#[non_exhaustive]
pub struct Session {
Show 21 fields pub application_id: String, pub session_id: String, pub arn: String, pub name: Option<String>, pub state: SessionState, pub state_details: String, pub release_label: String, pub execution_role_arn: String, pub created_by: String, pub created_at: DateTime, pub updated_at: DateTime, pub started_at: Option<DateTime>, pub ended_at: Option<DateTime>, pub idle_since: Option<DateTime>, pub configuration_overrides: Option<SessionConfigurationOverrides>, pub network_configuration: Option<NetworkConfiguration>, pub idle_timeout_minutes: Option<i64>, pub tags: Option<HashMap<String, String>>, pub total_resource_utilization: Option<TotalResourceUtilization>, pub billed_resource_utilization: Option<ResourceUtilization>, pub total_execution_duration_seconds: Option<i64>,
}
Information about a session, including the session state, configuration, and timestamps.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
application_id: String

The ID of the application that the session belongs to.

session_id: String

The ID of the session.

arn: String

The Amazon Resource Name (ARN) of the session.

name: Option<String>

The optional name of the session.

state: SessionState

The state of the session.

state_details: String

Additional details about the current state of the session.

release_label: String

The Amazon EMR release label associated with the session.

execution_role_arn: String

The Amazon Resource Name (ARN) of the execution role for the session.

created_by: String

The IAM principal that created the session.

created_at: DateTime

The date and time that the session was created.

updated_at: DateTime

The date and time that the session was last updated.

started_at: Option<DateTime>

The date and time that the session moved to a running state.

ended_at: Option<DateTime>

The date and time that the session was terminated or failed.

idle_since: Option<DateTime>

The date and time that the session became idle.

configuration_overrides: Option<SessionConfigurationOverrides>

The configuration overrides for the session, including runtime configuration properties.

network_configuration: Option<NetworkConfiguration>

The network configuration for customer VPC connectivity for the session.

idle_timeout_minutes: Option<i64>

The idle timeout in minutes for the session. After the session remains idle for this duration, it is automatically terminated.

tags: Option<HashMap<String, String>>

The tags assigned to the session.

total_resource_utilization: Option<TotalResourceUtilization>

The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.

billed_resource_utilization: Option<ResourceUtilization>

The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.

total_execution_duration_seconds: Option<i64>

The total execution duration of the session in seconds.

Implementations

Source

impl Session

pub fn application_id(&self) -> &str

The ID of the application that the session belongs to.

pub fn session_id(&self) -> &str

The ID of the session.

pub fn arn(&self) -> &str

The Amazon Resource Name (ARN) of the session.

pub fn name(&self) -> Option<&str>

The optional name of the session.

pub fn state(&self) -> &SessionState

The state of the session.

pub fn state_details(&self) -> &str

Additional details about the current state of the session.

pub fn release_label(&self) -> &str

The Amazon EMR release label associated with the session.

pub fn execution_role_arn(&self) -> &str

The Amazon Resource Name (ARN) of the execution role for the session.

pub fn created_by(&self) -> &str

The IAM principal that created the session.

pub fn created_at(&self) -> &DateTime

The date and time that the session was created.

pub fn updated_at(&self) -> &DateTime

The date and time that the session was last updated.

pub fn started_at(&self) -> Option<&DateTime>

The date and time that the session moved to a running state.

pub fn ended_at(&self) -> Option<&DateTime>

The date and time that the session was terminated or failed.

pub fn idle_since(&self) -> Option<&DateTime>

The date and time that the session became idle.

pub fn configuration_overrides(&self) -> Option<&SessionConfigurationOverrides>

The configuration overrides for the session, including runtime configuration properties.

pub fn network_configuration(&self) -> Option<&NetworkConfiguration>

The network configuration for customer VPC connectivity for the session.

pub fn idle_timeout_minutes(&self) -> Option<i64>

The idle timeout in minutes for the session. After the session remains idle for this duration, it is automatically terminated.

pub fn tags(&self) -> Option<&HashMap<String, String>>

The tags assigned to the session.

pub fn total_resource_utilization(&self) -> Option<&TotalResourceUtilization>

The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.

pub fn billed_resource_utilization(&self) -> Option<&ResourceUtilization>

The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.

pub fn total_execution_duration_seconds(&self) -> Option<i64>

The total execution duration of the session in seconds.

Source

impl Session

pub fn builder() -> SessionBuilder

Creates a new builder-style object to manufacture Session.