#[non_exhaustive]pub struct SessionConfigurationOverrides {
pub runtime_configuration: Option<Vec<Configuration>>,
}Expand description
The configuration overrides for a session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.runtime_configuration: Option<Vec<Configuration>>The runtime configuration for the session. Contains Spark configuration properties specified at session creation time.
Implementations
Sourceimpl SessionConfigurationOverrides
impl SessionConfigurationOverrides
Sourcepub fn runtime_configuration(&self) -> &[Configuration]
pub fn runtime_configuration(&self) -> &[Configuration]
The runtime configuration for the session. Contains Spark configuration properties specified at session creation time.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .runtime_configuration.is_none().
Sourceimpl SessionConfigurationOverrides
impl SessionConfigurationOverrides
Sourcepub fn builder() -> SessionConfigurationOverridesBuilder
pub fn builder() -> SessionConfigurationOverridesBuilder
Creates a new builder-style object to manufacture SessionConfigurationOverrides.