#[non_exhaustive]pub struct Session {Show 21 fields
pub application_id: String,
pub session_id: String,
pub arn: String,
pub name: Option<String>,
pub state: SessionState,
pub state_details: String,
pub release_label: String,
pub execution_role_arn: String,
pub created_by: String,
pub created_at: DateTime,
pub updated_at: DateTime,
pub started_at: Option<DateTime>,
pub ended_at: Option<DateTime>,
pub idle_since: Option<DateTime>,
pub configuration_overrides: Option<SessionConfigurationOverrides>,
pub network_configuration: Option<NetworkConfiguration>,
pub idle_timeout_minutes: Option<i64>,
pub tags: Option<HashMap<String, String>>,
pub total_resource_utilization: Option<TotalResourceUtilization>,
pub billed_resource_utilization: Option<ResourceUtilization>,
pub total_execution_duration_seconds: Option<i64>,
}Expand description
Information about a session, including the session state, configuration, and timestamps.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_id: StringThe ID of the application that the session belongs to.
session_id: StringThe ID of the session.
arn: StringThe Amazon Resource Name (ARN) of the session.
name: Option<String>The optional name of the session.
state: SessionStateThe state of the session.
state_details: StringAdditional details about the current state of the session.
release_label: StringThe Amazon EMR release label associated with the session.
execution_role_arn: StringThe Amazon Resource Name (ARN) of the execution role for the session.
created_by: StringThe IAM principal that created the session.
created_at: DateTimeThe date and time that the session was created.
updated_at: DateTimeThe date and time that the session was last updated.
started_at: Option<DateTime>The date and time that the session moved to a running state.
ended_at: Option<DateTime>The date and time that the session was terminated or failed.
idle_since: Option<DateTime>The date and time that the session became idle.
configuration_overrides: Option<SessionConfigurationOverrides>The configuration overrides for the session, including runtime configuration properties.
network_configuration: Option<NetworkConfiguration>The network configuration for customer VPC connectivity for the session.
idle_timeout_minutes: Option<i64>The idle timeout in minutes for the session. After the session remains idle for this duration, it is automatically terminated.
The tags assigned to the session.
total_resource_utilization: Option<TotalResourceUtilization>The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.
billed_resource_utilization: Option<ResourceUtilization>The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.
total_execution_duration_seconds: Option<i64>The total execution duration of the session in seconds.
Implementations
Sourceimpl Session
impl Session
Sourcepub fn application_id(&self) -> &str
pub fn application_id(&self) -> &str
The ID of the application that the session belongs to.
Sourcepub fn session_id(&self) -> &str
pub fn session_id(&self) -> &str
The ID of the session.
Sourcepub fn state(&self) -> &SessionState
pub fn state(&self) -> &SessionState
The state of the session.
Sourcepub fn state_details(&self) -> &str
pub fn state_details(&self) -> &str
Additional details about the current state of the session.
Sourcepub fn release_label(&self) -> &str
pub fn release_label(&self) -> &str
The Amazon EMR release label associated with the session.
Sourcepub fn execution_role_arn(&self) -> &str
pub fn execution_role_arn(&self) -> &str
The Amazon Resource Name (ARN) of the execution role for the session.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
The IAM principal that created the session.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time that the session was created.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The date and time that the session was last updated.
Sourcepub fn started_at(&self) -> Option<&DateTime>
pub fn started_at(&self) -> Option<&DateTime>
The date and time that the session moved to a running state.
Sourcepub fn ended_at(&self) -> Option<&DateTime>
pub fn ended_at(&self) -> Option<&DateTime>
The date and time that the session was terminated or failed.
Sourcepub fn idle_since(&self) -> Option<&DateTime>
pub fn idle_since(&self) -> Option<&DateTime>
The date and time that the session became idle.
Sourcepub fn configuration_overrides(&self) -> Option<&SessionConfigurationOverrides>
pub fn configuration_overrides(&self) -> Option<&SessionConfigurationOverrides>
The configuration overrides for the session, including runtime configuration properties.
Sourcepub fn network_configuration(&self) -> Option<&NetworkConfiguration>
pub fn network_configuration(&self) -> Option<&NetworkConfiguration>
The network configuration for customer VPC connectivity for the session.
Sourcepub fn idle_timeout_minutes(&self) -> Option<i64>
pub fn idle_timeout_minutes(&self) -> Option<i64>
The idle timeout in minutes for the session. After the session remains idle for this duration, it is automatically terminated.
The tags assigned to the session.
Sourcepub fn total_resource_utilization(&self) -> Option<&TotalResourceUtilization>
pub fn total_resource_utilization(&self) -> Option<&TotalResourceUtilization>
The aggregate vCPU, memory, and storage resources used from the time the session starts to execute, until the time the session terminates, rounded up to the nearest second.
Sourcepub fn billed_resource_utilization(&self) -> Option<&ResourceUtilization>
pub fn billed_resource_utilization(&self) -> Option<&ResourceUtilization>
The aggregate vCPU, memory, and storage that Amazon Web Services has billed for the session. The billed resources include a 1-minute minimum usage for workers, plus additional storage over 20 GB per worker. Note that billed resources do not include usage for idle pre-initialized workers.
Sourcepub fn total_execution_duration_seconds(&self) -> Option<i64>
pub fn total_execution_duration_seconds(&self) -> Option<i64>
The total execution duration of the session in seconds.